@@ -1,22 +1,17 @@
 /* 
-Copyright Paul James Mutton, 2001-2003, http://www.jibble.org/
+Copyright Paul James Mutton, 2001-2009, http://www.jibble.org/
 
 This file is part of PircBot.
 
-You may freely use PircBot to make your own IRC bots and clients.
+This software is dual-licensed, allowing you to choose between the GNU
+General Public License (GPL) and the www.jibble.org Commercial License.
+Since the GPL may be too restrictive for use in a proprietary application,
+a commercial license is also provided. Full license information can be
+found at http://www.jibble.org/licenses/
 
-Any software that makes use of the PircBot package must clearly
-state that it makes use of the PircBot Java IRC Bot Framework (or
-some similar wording) found at http://www.jibble.org/
-
-This source code, or parts thereof, may not be distributed in any
-modified form without permission from the author.
-
-PircBot is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
 
+
 package org.jibble.pircbot;
 
 import java.net.*;
@@ -28,7 +23,7 @@ import java.io.*;
  * @since   0.9c
  * @author  Paul James Mutton,
  *          <a href="http://www.jibble.org/">http://www.jibble.org/</a>
- * @version 1.0.3 (Build time: Sat Jan 18 23:29:54 2003)
+ * @version    1.5.0 (Build time: Mon Dec 14 20:07:17 2009)
  */
 public class DccChat {
     
@@ -45,12 +40,14 @@ public class DccChat {
      * 
      * @throws IOException If the connection cannot be made.
      */
-    protected DccChat(PircBot bot, String sourceNick, String address, int port) throws IOException {
+    DccChat(PircBot bot, String nick, String login, String hostname, long address, int port) {
         _bot = bot;
-        _sourceNick = sourceNick;
-        _socket = new Socket(address, port);
-        _reader = new BufferedReader(new InputStreamReader(_socket.getInputStream()));
-        _writer = new BufferedWriter(new OutputStreamWriter(_socket.getOutputStream()));
+        _address = address;
+        _port = port;
+        _nick = nick;
+        _login = login;
+        _hostname = hostname;
+        _acceptable = true;
     }
     
     
@@ -65,12 +62,31 @@ public class DccChat {
      * 
      * @throws IOException If the socket cannot be read from.
      */
-    protected DccChat(PircBot bot, String sourceNick, Socket socket) throws IOException {
+    DccChat(PircBot bot, String nick, Socket socket) throws IOException {
         _bot = bot;
-        _sourceNick = sourceNick;
+        _nick = nick;
         _socket = socket;
         _reader = new BufferedReader(new InputStreamReader(_socket.getInputStream()));
-        _writer = new BufferedWriter(new OutputStreamWriter(_socket.getOutputStream()));        
+        _writer = new BufferedWriter(new OutputStreamWriter(_socket.getOutputStream()));
+        _acceptable = false;
+    }
+    
+    
+    /**
+     * Accept this DccChat connection.
+     * 
+     * @since 1.2.0
+     * 
+     */
+    public synchronized void accept() throws IOException {
+        if (_acceptable) {
+            _acceptable = false;
+            int[] ip = _bot.longToIp(_address);
+            String ipStr = ip[0] + "." + ip[1] + "." + ip[2] + "." + ip[3];
+            _socket = new Socket(ipStr, _port);
+            _reader = new BufferedReader(new InputStreamReader(_socket.getInputStream()));
+            _writer = new BufferedWriter(new OutputStreamWriter(_socket.getOutputStream()));            
+        }
     }
     
     
@@ -85,11 +101,10 @@ public class DccChat {
      * @throws IOException If an I/O error occurs.
      */
     public String readLine() throws IOException {
-        String line = _reader.readLine();
-        if (line != null) {
-            _bot.log("+++ DCC CHAT " + _sourceNick + " " + line);
+        if (_acceptable) {
+            throw new IOException("You must call the accept() method of the DccChat request before you can use it.");
         }
-        return line;
+        return _reader.readLine();
     }
     
     
@@ -103,8 +118,10 @@ public class DccChat {
      * @throws IOException If an I/O error occurs.
      */
     public void sendLine(String line) throws IOException {
+        if (_acceptable) {
+            throw new IOException("You must call the accept() method of the DccChat request before you can use it.");
+        }
         // No need for synchronization here really...
-        _bot.log("+++ DCC CHAT " + _sourceNick + " >>>" + line);
         _writer.write(line + "\r\n");
         _writer.flush();
     }
@@ -116,14 +133,95 @@ public class DccChat {
      * @throws IOException If an I/O error occurs.
      */
     public void close() throws IOException {
-        _bot.log("+++ DCC CHAT with " + _sourceNick + " ended by us.");
+        if (_acceptable) {
+            throw new IOException("You must call the accept() method of the DccChat request before you can use it.");
+        }
         _socket.close();
     }
     
+    
+    /**
+     * Returns the nick of the other user taking part in this file transfer.
+     * 
+     * @return the nick of the other user.
+     * 
+     */
+    public String getNick() {
+        return _nick;
+    }
+
+
+    /**
+     * Returns the login of the DCC Chat initiator.
+     * 
+     * @return the login of the DCC Chat initiator. null if we sent it.
+     * 
+     */
+    public String getLogin() {
+        return _login;
+    }
+
+
+    /**
+     * Returns the hostname of the DCC Chat initiator.
+     * 
+     * @return the hostname of the DCC Chat initiator. null if we sent it.
+     * 
+     */
+    public String getHostname() {
+        return _hostname;
+    }
+    
+    
+    /**
+     * Returns the BufferedReader used by this DCC Chat.
+     * 
+     * @return the BufferedReader used by this DCC Chat.
+     */
+    public BufferedReader getBufferedReader() {
+        return _reader;
+    }
+
+
+    /**
+     * Returns the BufferedReader used by this DCC Chat.
+     * 
+     * @return the BufferedReader used by this DCC Chat.
+     */
+    public BufferedWriter getBufferedWriter() {
+        return _writer;
+    }
+    
+    
+    /**
+     * Returns the raw Socket used by this DCC Chat.
+     * 
+     * @return the raw Socket used by this DCC Chat.
+     */
+    public Socket getSocket() {
+        return _socket;
+    }
+    
+    
+    /**
+     * Returns the address of the sender as a long.
+     *
+     * @return the address of the sender as a long.
+     */
+    public long getNumericalAddress() {
+        return _address;
+    }
+
+    
     private PircBot _bot;
-    private String _sourceNick;
+    private String _nick;
+    private String _login = null;
+    private String _hostname = null;
     private BufferedReader _reader;
     private BufferedWriter _writer;
     private Socket _socket;
+    private boolean _acceptable;
+    private long _address = 0;
+    private int _port = 0;
     
-}
\ No newline at end of file
+}
