@@ -1,22 +1,17 @@
 /* 
-Copyright Paul James Mutton, 2001-2003, http://www.jibble.org/
+Copyright Paul James Mutton, 2001-2009, http://www.jibble.org/
 
 This file is part of PircBot.
 
-You may freely use PircBot to make your own IRC bots and clients.
+This software is dual-licensed, allowing you to choose between the GNU
+General Public License (GPL) and the www.jibble.org Commercial License.
+Since the GPL may be too restrictive for use in a proprietary application,
+a commercial license is also provided. Full license information can be
+found at http://www.jibble.org/licenses/
 
-Any software that makes use of the PircBot package must clearly
-state that it makes use of the PircBot Java IRC Bot Framework (or
-some similar wording) found at http://www.jibble.org/
-
-This source code, or parts thereof, may not be distributed in any
-modified form without permission from the author.
-
-PircBot is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
 
+
 package org.jibble.pircbot;
 
 import java.net.*;
@@ -44,7 +39,7 @@ import java.io.*;
  * @since   0.9c
  * @author  Paul James Mutton,
  *          <a href="http://www.jibble.org/">http://www.jibble.org/</a>
- * @version 1.0.3 (Build time: Sat Jan 18 23:29:54 2003)
+ * @version    1.5.0 (Build time: Mon Dec 14 20:07:17 2009)
  */
 public class IdentServer extends Thread {
     
@@ -61,7 +56,7 @@ public class IdentServer extends Thread {
      * @param bot The PircBot instance that will be used to log to.
      * @param login The login that the ident server will respond with.
      */
-    public IdentServer(PircBot bot, String login) {
+    IdentServer(PircBot bot, String login) {
         _bot = bot;
         _login = login;
 
@@ -75,6 +70,7 @@ public class IdentServer extends Thread {
         }
         
         _bot.log("*** Ident server running on port 113 for the next 60 seconds...");
+        this.setName(this.getClass() + "-Thread");
         this.start();
     }
     
@@ -120,4 +116,4 @@ public class IdentServer extends Thread {
     private String _login;
     private ServerSocket _ss = null;
     
-}
\ No newline at end of file
+}
