@@ -1,22 +1,17 @@
 /* 
-Copyright Paul James Mutton, 2001-2003, http://www.jibble.org/
+Copyright Paul James Mutton, 2001-2009, http://www.jibble.org/
 
 This file is part of PircBot.
 
-You may freely use PircBot to make your own IRC bots and clients.
+This software is dual-licensed, allowing you to choose between the GNU
+General Public License (GPL) and the www.jibble.org Commercial License.
+Since the GPL may be too restrictive for use in a proprietary application,
+a commercial license is also provided. Full license information can be
+found at http://www.jibble.org/licenses/
 
-Any software that makes use of the PircBot package must clearly
-state that it makes use of the PircBot Java IRC Bot Framework (or
-some similar wording) found at http://www.jibble.org/
-
-This source code, or parts thereof, may not be distributed in any
-modified form without permission from the author.
-
-PircBot is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
 
+
 package org.jibble.pircbot;
 
 import java.io.*;
@@ -31,7 +26,7 @@ import java.util.*;
  *
  * @author  Paul James Mutton,
  *          <a href="http://www.jibble.org/">http://www.jibble.org/</a>
- * @version 1.0.3 (Build time: Sat Jan 18 23:29:54 2003)
+ * @version    1.5.0 (Build time: Mon Dec 14 20:07:17 2009)
  */
 public class InputThread extends Thread {
     
@@ -43,11 +38,12 @@ public class InputThread extends Thread {
      * @param breader The BufferedReader that reads lines from the server.
      * @param bwriter The BufferedWriter that sends lines to the server.
      */
-    protected InputThread(PircBot bot, Socket socket, BufferedReader breader, BufferedWriter bwriter) {
+    InputThread(PircBot bot, Socket socket, BufferedReader breader, BufferedWriter bwriter) {
         _bot = bot;
         _socket = socket;
         _breader = breader;
         _bwriter = bwriter;
+        this.setName(this.getClass() + "-Thread");
     }
     
     
@@ -57,7 +53,7 @@ public class InputThread extends Thread {
      *
      * @param line The raw line to send to the IRC server.
      */
-    public void sendRawLine(String line) {
+    void sendRawLine(String line) {
         OutputThread.sendRawLine(_bot, _bwriter, line);
     }
     
@@ -69,7 +65,7 @@ public class InputThread extends Thread {
      * 
      * @return True if still connected.
      */
-    public boolean isConnected() {
+    boolean isConnected() {
         return _isConnected;
     }
     
@@ -86,8 +82,8 @@ public class InputThread extends Thread {
      * in your code is something you should really fix.
      */
     public void run() {
-        boolean running = true;
         try {
+            boolean running = true;
             while (running) {
                 try {
                     String line = null;
@@ -138,18 +134,36 @@ public class InputThread extends Thread {
         catch (Exception e) {
             // Just assume the socket was already closed.
         }
-        _isConnected = false;
-        _bot.log("*** Disconnected.");
-        _bot.onDisconnect();
+
+        if (!_disposed) {
+            _bot.log("*** Disconnected.");        
+            _isConnected = false;
+            _bot.onDisconnect();
+        }
         
     }
     
+    
+    /**
+     * Closes the socket without onDisconnect being called subsequently.
+     */
+    public void dispose () {
+        try {
+            _disposed = true;
+            _socket.close();
+        }
+        catch (Exception e) {
+            // Do nothing.
+        }
+    }
+    
     private PircBot _bot = null;
     private Socket _socket = null;
     private BufferedReader _breader = null;
     private BufferedWriter _bwriter = null;
     private boolean _isConnected = true;
+    private boolean _disposed = false;
     
     public static final int MAX_LINE_LENGTH = 512;
     
-}
\ No newline at end of file
+}
