@@ -1,22 +1,17 @@
 /* 
-Copyright Paul James Mutton, 2001-2003, http://www.jibble.org/
+Copyright Paul James Mutton, 2001-2009, http://www.jibble.org/
 
 This file is part of PircBot.
 
-You may freely use PircBot to make your own IRC bots and clients.
+This software is dual-licensed, allowing you to choose between the GNU
+General Public License (GPL) and the www.jibble.org Commercial License.
+Since the GPL may be too restrictive for use in a proprietary application,
+a commercial license is also provided. Full license information can be
+found at http://www.jibble.org/licenses/
 
-Any software that makes use of the PircBot package must clearly
-state that it makes use of the PircBot Java IRC Bot Framework (or
-some similar wording) found at http://www.jibble.org/
-
-This source code, or parts thereof, may not be distributed in any
-modified form without permission from the author.
-
-PircBot is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */
 
+
 package org.jibble.pircbot;
 
 import java.io.*;
@@ -31,7 +26,7 @@ import java.net.*;
  *
  * @author  Paul James Mutton,
  *          <a href="http://www.jibble.org/">http://www.jibble.org/</a>
- * @version 1.0.3 (Build time: Sat Jan 18 23:29:54 2003)
+ * @version    1.5.0 (Build time: Mon Dec 14 20:07:17 2009)
  */
 public class OutputThread extends Thread {
     
@@ -45,28 +40,31 @@ public class OutputThread extends Thread {
      * @param bot The underlying PircBot instance.
      * @param outQueue The Queue from which we will obtain our messages.
      */
-    protected OutputThread(PircBot bot, Queue outQueue) {
+    OutputThread(PircBot bot, Queue outQueue) {
         _bot = bot;
         _outQueue = outQueue;
+        this.setName(this.getClass() + "-Thread");
     }
     
     
     /**
-     * A static method to write a line to a BufferedWriter and then pass
+     * A static method to write a line to a BufferedOutputStream and then pass
      * the line to the log method of the supplied PircBot instance.
      * 
      * @param bot The underlying PircBot instance.
-     * @param writer The BufferedWriter to write to.
+     * @param out The BufferedOutputStream to write to.
      * @param line The line to be written. "\r\n" is appended to the end.
+     * @param encoding The charset to use when encoing this string into a
+     *                 byte array.
      */
-    public static void sendRawLine(PircBot bot, BufferedWriter writer, String line) {
+    static void sendRawLine(PircBot bot, BufferedWriter bwriter, String line) {
         if (line.length() > bot.getMaxLineLength() - 2) {
             line = line.substring(0, bot.getMaxLineLength() - 2);
         }
-        synchronized(writer) {
+        synchronized(bwriter) {
             try {
-                writer.write(line + "\r\n");
-                writer.flush();
+                bwriter.write(line + "\r\n");
+                bwriter.flush();
                 bot.log(">>>" + line);
             }
             catch (Exception e) {
@@ -79,24 +77,29 @@ public class OutputThread extends Thread {
     /**
      * This method starts the Thread consuming from the outgoing message
      * Queue and sending lines to the server.
-     *
      */
     public void run() {
-        boolean running = true;
-        while (running) {
-            // Small delay to prevent spamming of the channel
-            try {
+        try {
+            boolean running = true;
+            while (running) {
+                // Small delay to prevent spamming of the channel
                 Thread.sleep(_bot.getMessageDelay());
+                
+                String line = (String) _outQueue.next();
+                if (line != null) {
+                    _bot.sendRawLine(line);
+                }
+                else {
+                    running = false;
+                }
             }
-            catch (InterruptedException e) {
-                // Do nothing.
-            }
-            String line = (String) _outQueue.next();
-            _bot.sendRawLine(line);
+        }
+        catch (InterruptedException e) {
+            // Just let the method return naturally...
         }
     }
     
     private PircBot _bot = null;
     private Queue _outQueue = null;
     
-}
\ No newline at end of file
+}
